const wasmURL = new URL('cli.wasm', import.meta.url)

export { wasmURL }
